@@ -27,5 +27,5 @@ class Server:
 
         try: self.userCount: int = data["users"]
         except (KeyError, TypeError): self.userCount: int = -1
-        # try: self.bumpCount: int = data["bumps"]
-        # except (KeyError, TypeError): self.bumpCount: int = -1
\ No newline at end of file
+        try: self.bumpCount: int = data["bumps"]
+        except (KeyError, TypeError): self.bumpCount: int = -1
\ No newline at end of file
